@@ -14,7 +14,7 @@ use constant SKIP      => 2;
 #inherits Apache::Session
 #link Lemonldap::NG::Common::Apache::Session::SOAP protected globalStorage
 
-our $VERSION = '1.9.4';
+our $VERSION = '1.9.6';
 our ( %EXPORT_TAGS, @EXPORT_OK, @EXPORT );
 
 our $tsv = {};    # Hash ref containing thread-shared values, filled
@@ -222,7 +222,10 @@ sub retrieveSession {
         }
 
         # Update the session to notify activity, if necessary
-        if ( $tsv->{timeoutActivity} and ( $now - $datas->{_lastSeen} > 60 ) ) {
+        if ( $tsv->{timeoutActivity}
+            and
+            ( $now - $datas->{_lastSeen} > $tsv->{timeoutActivityInterval} ) )
+        {
             $session->update( { '_lastSeen' => $now } );
 
             if ( $session->error ) {
