@@ -4,21 +4,26 @@ use 5.10.0;
 use Mouse;
 use Lemonldap::NG::Handler::SharedConf qw(:tsv :variables :jailSharedVars);
 
-our $VERSION = '1.9.1';
+our $VERSION = '1.9.6';
 
 has protection => ( is => 'rw', isa => 'Str' );
 has rule       => ( is => 'rw', isa => 'Str' );
 
+has subhandler => (
+    is      => 'rw',
+    default => 'Lemonldap::NG::Handler::SharedConf'
+);
+
 ## @method boolean init($args)
 # Initalize main handler
 sub init {
     my ( $self, $args ) = @_;
-    eval { Lemonldap::NG::Handler::SharedConf->init($self) };
+    eval { $self->subhandler->init($self) };
     if ( $@ and not $self->{protection} eq 'none' ) {
         $self->error($@);
         return 0;
     }
-    unless ( Lemonldap::NG::Handler::SharedConf->checkConf($self)
+    unless ( $self->subhandler->checkConf($self)
         or $self->{protection} eq 'none' )
     {
         $self->error(
@@ -57,7 +62,7 @@ sub _run {
         # Check if main handler initialization has been done
         unless (%$tsv) {
             $self->lmLog( 'Checking conf', 'debug' );
-            eval { Lemonldap::NG::Handler::SharedConf->checkConf() };
+            eval { $self->subhandler->checkConf() };
             $self->lmLog( $@, 'error' ) if ($@);
         }
 
@@ -76,13 +81,13 @@ sub status {
 
     # Check if main handler initialization has been done
     unless (%$tsv) {
-        eval { Lemonldap::NG::Handler::SharedConf->checkConf() };
+        eval { $class->subhandler->checkConf() };
         $class->lmLog( $@, 'error' ) if ($@);
     }
     return sub {
         my $req = Lemonldap::NG::Common::PSGI::Request->new( $_[0] );
         Lemonldap::NG::Handler::API->newRequest($req);
-        Lemonldap::NG::Handler::SharedConf->status();
+        $class->subhandler->status();
         return [ 200, [ %{ $req->{respHeaders} } ], [ $req->{respBody} ] ];
     };
 }
@@ -93,7 +98,7 @@ sub status {
 sub _authAndTrace {
     my ( $self, $req ) = @_;
     Lemonldap::NG::Handler::API->newRequest($req);
-    my $res = Lemonldap::NG::Handler::SharedConf->run( $self->{rule} );
+    my $res = $self->subhandler->run( $self->{rule} );
     $self->portal( $tsv->{portal}->() );
     $req->userData($datas) if ($datas);
 
@@ -122,14 +127,18 @@ sub _authAndTrace {
 # @return hash of user datas
 sub user {
     my ( $self, $req ) = @_;
-    return $req->userData || { $Lemonldap::NG::Handler::Main::tsv->{whatToTrace} || _whatToTrace => 'anonymous' };
+    return $req->userData
+      || { $Lemonldap::NG::Handler::Main::tsv->{whatToTrace}
+          || _whatToTrace => 'anonymous' };
 }
 
 ## @method string userId()
 # @return user identifier to log
 sub userId {
     my ( $self, $req ) = @_;
-    return $req->userData->{$Lemonldap::NG::Handler::Main::tsv->{whatToTrace} || '_whatToTrace'} || 'anonymous';
+    return $req->userData->{ $Lemonldap::NG::Handler::Main::tsv->{whatToTrace}
+          || '_whatToTrace' }
+      || 'anonymous';
 }
 
 ## @method boolean group(string group)
